@@ -131,9 +131,8 @@ class Peak:
             raise ValueError('mask and peak have different axes')
 
         try:
-            return mask.ppm_in_mask(
-                peak_ppm=self.get_par('*_PPM'),
-                peak_axis_property=self.axis,
+            return mask.peak_in_mask(
+                peak=self,
                 box_radius=box_radius,
             )
         except PeakOutsideOfMaskError as e:
@@ -208,6 +207,8 @@ class PeakTable:
 
         try:
             self._set_carrier_frequency(**kwargs)
+        except (AttributeError, ValueError):
+            raise
         except Exception as e:
             raise ParsePeakTableError(f'failed to set carrier frequency: {self.file}\n{e}')
 
@@ -247,19 +248,19 @@ class PeakTable:
 
         elif isinstance(carrier_frequency, AxisData):
             if carrier_frequency.keys() != self.axis.keys():
-                raise AttributeError('The axes for the given carrier frequency data dot match those of the peak table')
+                raise AttributeError('The axes for the given carrier frequency data do not match those of the peak table')
             # extract ONLY the carrier frequency values from the carrier_frequency AxisData object
             # this object could contain other properties that we don't want
             self.axis.set_data(carrier_frequency.get('carrier_frequency'))
 
         else:
-            msg = 'define carrier frequency by providing a list of lists: [key, cf, cf_units]'
+            msg = 'define carrier frequency by providing a list of lists: [axis, cf, cf_units]'
             if not is_iterable(carrier_frequency):
                 raise ValueError(msg)
 
             for info in carrier_frequency:
                 try:
-                    key, cf, cf_units = info
+                    axis, cf, cf_units = info
                 except ValueError:
                     raise ValueError(msg)
 
@@ -271,7 +272,7 @@ class PeakTable:
                     raise ValueError(f'do not recognize units for carrier frequency: {cf_units}.  must use "Hz" or "MHz"')
 
                 self.axis.set(
-                    axis=key,
+                    axis=axis,
                     name='carrier_frequency',
                     value=cf_hz,
                     unit='Hz',
@@ -480,10 +481,19 @@ class PeakTablePipe(PeakTable):
         You probably don't want to create a PeakTablePipe object - it is just a super-class to provide common tasks.
         """
         # pre
+        self.REMARK = []
+        self.DATA = []
         self.VARS = None
         self.FORMAT = None
 
-        super().__init__(file, **kwargs)
+        try:
+            super().__init__(file, **kwargs)
+        except ParsePeakTableError as e:
+            # raise ParsePeakTableError(e)
+            raise
+        except Exception as e:
+            # raise ParsePeakTableError(e)
+            raise
 
     def _parse_file(self):
         """
@@ -521,7 +531,7 @@ class PeakTablePipe(PeakTable):
 
                 if mode == 'genSimTab':
                     if line.startswith('#'):
-                        self.genSimTab.append(line.strip().lstrip('#').rstrip('\\').strip())
+                        self.genSimTab_raw_list.append(line.strip().lstrip('#').rstrip('\\').strip())
                         continue
                     else:
                         mode = 'data'
@@ -530,6 +540,7 @@ class PeakTablePipe(PeakTable):
                     if line.startswith('DATA'):
                         # axis properties are described like this
                         # example: DATA  X_AXIS HN           1   659   10.297ppm    5.798ppm
+                        self.DATA.append(line)
                         info = line.split()
                         try:
                             if info[1] == 'CLUSTER':
@@ -591,12 +602,70 @@ class PeakTablePipe(PeakTable):
                             axis_property=self.axis,
                         ))
 
+    def _build_genSimTab_comment(self):
+        """
+        convert list of genSimTab lines into a single comment string that can be written into header of peak table
+        :return:
+        """
+        try:
+            join_str = ' \\\n#' + ' ' * 15
+            return '# ' + join_str.join(self.genSimTab_raw_list)
+        except AttributeError:
+            raise AttributeError
+
+    def write(self, file):
+        """
+        write a peak table to file.  include (if available) genSimTab, REMARK, DATA, VARS, FORMAT, and peak table
+        :param file:
+        :return:
+        """
+        try:
+            with open(file, 'w') as f_out:
+                try:
+                    f_out.write(self._build_genSimTab_comment())
+                    f_out.write('\n\n')
+                except AttributeError:
+                    pass
+
+                if self.REMARK:
+                    for line in self.REMARK:
+                        f_out.write(line + '\n')
+                    f_out.write('\n')
+
+                if self.DATA:
+                    for line in self.DATA:
+                        f_out.write(line + '\n')
+                    f_out.write('\n')
+
+                # build the FORMAT and VARS lines in the same style as NMRPipe tables
+                vars_out   = 'VARS   '
+                format_out = 'FORMAT '
+                for vars_current, format_current in zip(self.VARS, self.FORMAT):
+                    width = max(len(vars_current), len(format_current))
+                    vars_out += f' {vars_current:<{width}}'
+                    format_out += f' {format_current:<{width}}'
+                f_out.write(vars_out + '\n')
+                f_out.write(format_out+ '\n')
+                f_out.write('\n')
+
+                for p in self.peaks:
+                    out = []
+                    for vars_name, format_spec in zip(self.VARS, self.FORMAT):
+                        val = p.get_par(par=vars_name)
+                        out.append(f'{val:{format_spec.lstrip("%")}}')
+                    f_out.write(' ' + ' '.join(out) + '\n')
+        except FileNotFoundError:
+            raise FileNotFoundError(f'bad file: {file}')
+        except PermissionError:
+            raise PermissionError(f'bad file: {file}')
+        except Exception as e:
+            raise Exception(e)
+
 
 class PeakTablePipeRec(PeakTablePipe):
     """This subclass is for capturing the peaks "recovered" from an experiment by the NMRPipe peak picker"""
     def __init__(self, file, **kwargs):
         # pre
-        self.REMARK = []
 
         try:
             super().__init__(file, **kwargs)
@@ -667,19 +736,26 @@ class PeakTablePipeInj(PeakTablePipe):
         kwargs['carrier_frequency'] = carrier_frequency
 
         # pre
-        self.genSimTab = []
+        # capture the lines of genSimTab command as they are formatted so they can be written to file if needed
+        self.genSimTab_raw_list = []
 
         try:
             super().__init__(file, **kwargs)
-        except:
-            raise ParsePeakTableError(f'failed to read peak table as type: PeakTablePipeInj\n{file}')
+        except (ParsePeakTableError, Exception) as e:
+            raise ParsePeakTableError(f'failed to read peak table as type: PeakTablePipeInj\n  table = {file}\n  error = {e}')
 
         # post
-        self.genSimTab = ' '.join(self.genSimTab)
+        self.genSimTab = ' '.join(self.genSimTab_raw_list)
         self._set_maxLW()
         self._post()
 
     def _set_maxLW(self):
+        """
+        #1. read LW params from genSimTab command (indirect)
+        #2. compute LW from injected peak table using X1/X3 (in pts) and converting to hz
+        :return:
+        """
+
         # parse through the tokens to find maxLW values for each axis
         tokens = self.genSimTab.split()
         for axis in self.axis.keys():
@@ -688,9 +764,35 @@ class PeakTablePipeInj(PeakTablePipe):
                 idx = tokens.index(f'-{dimension.lower()}wMax')
                 self.axis.set(
                     axis=axis,
-                    name='maxLW',
+                    name='maxLW-genSimTab',
                     value=float(tokens[idx + 1]),
                     unit='Hz',
                 )
             except (ValueError, IndexError):
                 pass
+
+        indel_width = np.asarray([self.get_par(f"{dim}3") - self.get_par(f"{dim}1") for dim in self.axis.dimensions()]).max(axis=1)
+        axis_ppm_range = np.asarray([abs(r.min-r.max) for r in self.axis.get_field('range')])
+        num_pts = np.asarray(self.axis.get_field('num_pts'))
+        ppm_per_indel = axis_ppm_range / num_pts
+        peak_width_ppm = indel_width * ppm_per_indel
+
+        cf_unit = self.axis.get_field(name='carrier_frequency', field='unit')
+        cf_value = self.axis.get_field(name='carrier_frequency', field='value')
+        cf_mhz = []
+        for unit, value in zip(cf_unit, cf_value):
+            if unit.lower() == 'hz':
+                cf_mhz.append(value / 1e6)
+            elif unit.lower() == 'mhz':
+                cf_mhz.append(cf_value)
+            else:
+                raise ValueError
+
+        peak_width_hz = peak_width_ppm * cf_mhz
+
+        self.axis.set_list(
+            axis_list=self.axis.keys(),
+            name='maxLW',
+            value_list=peak_width_hz,
+            unit='Hz',
+        )
