@@ -30,6 +30,7 @@ class roc:
             roi_list: list = None,
             index=None,
             cluster_type=None,
+            mask=None,
             mask_file=None,
             box_radius=2,
             chi2prob=None,
@@ -47,8 +48,9 @@ class roc:
         :param index: keep only peaks with given index values
         :param cluster_type: keep only peaks with given cluster type index
             NMRPipe currently uses: 1 = Peak, 2 = Random Noise, 3 = Truncation artifact
-        :param mask_file: spectra of the empty region used to filter out empirical from synthetic injected spectra that
-            ROC is looking to recover; an alternative to providing an already filtered peaklist
+        :param mask: nmrtoolbox.Mask object defining the empty region of a spectrum.  used to isolate regions where
+            synthetic peaks may be injected
+        :param mask_file: mask data in the tabular file format from ConnjurST
         :param box_radius: defines size of box around peak position when querying it against empty mask
         :param chi2prob: remove peaks whose widths are outliers along any of the dimensions using chi2 probability
             expressed as p-value on [0,1] interval
@@ -105,7 +107,12 @@ class roc:
 
         # ================================================
         self.mask = None
-        if mask_file is not None:
+        if mask is not None:
+            if isinstance(mask, Mask):
+                self.mask = mask
+            else:
+                raise TypeError('mask provided, but type is invalid')
+        elif mask_file is not None:
             print('Reading mask file.  This may take a while...')
 
             self.mask_file = mask_file
@@ -160,10 +167,6 @@ class roc:
         self.MRMF = self._MRMF()
 
     def _validate_input(self):
-        # sometimes proton is labeled as 1H or HN, so standardize on the more common HN
-        if '1H' in self.recovered_peaks.axis.keys() and 'HN' in self.injected_peaks.axis.keys():
-            self.recovered_peaks.axis['HN'] = self.recovered_peaks.axis.pop('1H')
-
         if self.injected_peaks.axis.keys() != self.recovered_peaks.axis.keys():
             raise ValueError('The injected and recovered peak tables have different axis labels.')
 
