@@ -48,7 +48,8 @@ class Data:
         print(f"{self.name} = {str(self.value)} [{self.unit}]")
 
 
-class TableData:
+class DND:
+    """Dictionary of Named Data (DND)"""
     def __init__(self):
         self.data = {}
 
@@ -61,32 +62,46 @@ class TableData:
         except KeyError as e:
             raise KeyError(e)
 
+    def get_field(self, name, field='value'):
+        # extract out just the desired field and return value
+        try:
+            return self.get(name=name).get(field=field)
+        except KeyError as e:
+            raise KeyError(e)
+
     def print(self):
         [d.print() for d in self.data.values()]
 
 
-class AxisData:
+class DDND:
     def __init__(self):
-        """dictionary of axis names where the values are dictionaries of Data objects"""
-        self.data = defaultdict(dict)
+        """Dictionary of Dictionary of Named Data (DDND)"""
+        self.data = defaultdict(DND)
 
-        # self.data[key] = Data(name, value, unit)
+        # self.data[key][name] = Data(name, value, unit)
         #   "key" : nucleus of the axis (HN, N15, CA, etc.)
         #   "name" : property that gets recorded
         #       for "name" = "dimension", the values should be: X, Y, Z, A (correspond to NMRPipe data)
 
-    def axis_keys(self):
+    def keys(self):
         return list(self.data.keys())
 
     def set(self, axis, name, value, unit=None):
         axis = axis.upper()
-        self.data[axis][name] = Data(name=name, value=value, unit=unit)
+        self.data[axis].set(name=name, value=value, unit=unit)
+
+    def set_list(self, name, value_list, unit=None, axis_list=None):
+        if axis_list is None:
+            axis_list = self.keys()
+
+        for axis, value in zip(axis_list, value_list):
+            self.set(axis=axis, name=name, value=value, unit=unit)
 
     def set_data(self, data):
-        if not isinstance(data, AxisData):
-            raise TypeError('input must be of type AxisData')
-        for ax in data.axis_keys():
-            self.data[ax] = {**self.data[ax], **data.data[ax]}
+        if not isinstance(data, DDND):
+            raise TypeError(f'input must be of type AxisData, not: {type(data)}')
+        for ax in data.keys():
+            self.data[ax].data = {**self.data[ax].data, **data.data[ax].data}
 
     def get(self, name, axis=None):
         """
@@ -95,7 +110,7 @@ class AxisData:
         axis: name of axis (str) or list of axis names
         """
         if axis is None:
-            ax_list = self.axis_keys()
+            ax_list = self.keys()
         else:
             if not isinstance(axis, list):
                 axis = [axis]
@@ -104,10 +119,12 @@ class AxisData:
             except AttributeError:
                 raise AttributeError(f"axis should probably be 'X', 'Y', 'Z' or similar. unable to use: {str(axis)}")
 
-        out = AxisData()
+        out = DDND()
         try:
             for ax in ax_list:
-                out.data[ax][name] = self.data[ax][name]
+                if not isinstance(self.data[ax], DND):
+                    print('debugging test')
+                out.data[ax].data[name] = self.data[ax].get(name=name)
         except KeyError as e:
             raise KeyError(e)
         return out
@@ -117,17 +134,40 @@ class AxisData:
         # extract out just the desired field and return values in a list
         data_out = self.get(axis=axis, name=name)
         try:
-            return [data_out.data[ax][name].get(field) for ax in data_out.axis_keys()]
+            return [data_out.data[ax].get(name=name).get(field=field) for ax in data_out.keys()]
         except KeyError as e:
             raise KeyError(e)
 
     def print(self):
-        for axis in self.axis_keys():
+        for axis in self.keys():
             print(f"axis = {axis}")
             [d.print() for d in self.data[axis].values()]
 
 
-class ROI(AxisData):
+class AxisData(DDND):
+    """Subclass from DDND and provide a couple helper functions specific to NMR usage"""
+    # def num_dims(self):
+    #     """Number of dimensions"""
+    #     return len(self.keys())
+
+    def dimensions(self):
+        """Get the axis dimensions"""
+        return self.get_field(name='dimension')
+
+    def axis2dimension(self, axis):
+        """Convert an axis (e.g. 'HN') to a dimension (e.g. 'X')"""
+        try:
+            return self.get_field(name='dimension', axis=axis)[0]
+        except KeyError as e:
+            raise KeyError(e)
+
+
+class SpectrumData(DND):
+    """Subclass from DND and provide a couple helper functions specific to NMR usage"""
+    pass
+
+
+class ROI(DDND):
     def __init__(self, key_dimension_range):
         """
         Define a region of interest (ROI) by giving the min/max values along each axis
